/* PASM demo for use with Catalina IDE Precompiler and Compiler */

#include <stdio.h>

/* PASM Code for compilation using SpinC and inclusion as a data file
PASM Start mycogject.spin
CON
                                                                     ' add your values here
  _clkfreq = 80_000_000                                              ' 5Mhz Crystal
  _clkmode = xtal1 + pll16x                                          ' x 16

PUB Main
    coginit(1,@cogstart,0)                                           ' cog 1, cogstart, dummy value

DAT
                  org 0
cogstart
                  mov    temp2, par         ' parameters array
                  rdlong testaddress,temp2  ' hub location
                  add    temp2,#4           ' increment counter by 4 bytes = 1 long
                  rdlong temp, temp2        ' get data byte
                  wrlong temp, testaddress  ' store to hub
                  add    temp2,#4
                  add    testaddress,#4
                  rdlong temp, temp2        ' get data byte
                  wrlong temp, testaddress
                  add    temp2,#4
                  add    testaddress,#4
                  rdlong temp, temp2        ' get data byte
                  wrlong temp, testaddress
finish
                  jmp #finish

testaddress       long    0                 ' hub memory location
temp              long    0                 ' temp variable
temp2             long    0                 ' temp variable
                  fit     496
PASM End
*/ 

void mycogject(int cognumber, unsigned long *parameters_array)                                        // this name copied from the .spin name in the pasm section - names must match eg void mycogject matches mycogject.spin. Also first code after this must be the .h array file. Put your code after the };
{
       /**
       * @file mycogject_array.h
       * Created with spin.binary PASM to C Array Converter.
       * Copyright (c) 2011, John Doe
       */
       unsigned long mycogject_array[] =                               // dummy data or compiled above code or #include file.h
       {
              0x003c0602, 0x5c7c0000, 0x00001388, 0x00000041
       };
       _coginit((int)parameters_array>>2, (int)mycogject_array>>2, cognumber);  // array name built from spin file name
}

void clearscreen()                                                   // white text on dark blue background
{
       int i;
       for (i=0;i<40;i++)
       {
               t_setpos(0,0,i);                                      // move cursor to next line
               t_color(0,0x08FC);                                    // RRGGBBxx eg dark blue background 00001000 white text 11111100
       }
}

void sleep(int milliseconds)                                         // sleep function
{
       _waitcnt(_cnt()+(milliseconds*(_clockfreq()/1000))-4296);
}

char peek(int address)                                               // function implementation of peek
{
       return *((char *)address);
}

void poke(int address, char value)                                   // function implementation of poke
{
       *((char *)address) = value;
}

void main ()
{
       char c;
       int i;
       unsigned long hubaddress=100;
       unsigned long parameters_array[20];                            // for passing parameters to the cog
       parameters_array[0]=hubaddress;					               // hub address
       parameters_array[1]=80;						                  // some data to pass
       parameters_array[2]=81;
       parameters_array[3]=82;
       // clearscreen();  // for white on blue VGA, not needed for TV
       printf("Clock speed %u \n",_clockfreq());                     // see page 28 of the propeller manual for other useful commands
       printf("Catalina running in cog number %i \n",_cogid());      // integer
       i=hubaddress;                                               // location to peek and poke
       poke(i,66);                                                   // poke a B, the cog should change this
       printf("load cogject into cog 7\n");
       mycogject(7,parameters_array);                                                 // run in cog 7
       sleep(100);                                                   // pause to start up cog - if too short then reurns a B instead of a P
       c=peek(i);                                                    // peek byte at this location
       printf("Peek value at %i = character %c Ascii value %d \n",i,c,c);
       i=i+4;
       c=peek(i);
       printf("Peek value at %i = character %c Ascii value %d \n",i,c,c);
       i=i+4;
       c=peek(i);
       printf("Peek value at %i = character %c Ascii value %d \n",i,c,c);
       while (1); // Prop reboots on exit from main()
}

